# OIDCProxyUpstreamAuthentication

Controls how the proxy handles authentication with the ustream. Different upstream services may support different types of authentication. This controls whether those are allowed through, or whether the proxy participates in them on behalf of the user. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**ntlm** | [**OIDCProxyUpstreamNTLM**](OIDCProxyUpstreamNTLM.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


